<template>
  <basic-container>
    <ttable
      :table="table"
      @handleSelectionChange="handleSelectionChange"
      :uploadInfo="uploadInfo"
      :prelang="prelang"
      :options="options"
      :ajaxFun="ajaxFun"
      ref="resourceTable"
    >
      <template #toolbar></template>
    </ttable>
    <resource-dialog v-if="visible" ref="add" @refreshDataList="getData"></resource-dialog>
  </basic-container>
</template>

<script>
  import {fetchList, delObj} from '@/api/aps/resource'
  import {mapGetters} from 'vuex'
  import ResourceDialog from './resource-form.vue';
  import ttable from '@/views/common/ztt-table.vue';

  export default {
    components: {
      ResourceDialog,
      ttable
    },
    data () {
      return {
        ajaxFun:fetchList,
        visible: false,
        multipleSelection: [],
        uploadInfo:{//是否展示上传EXCEL以及对应的url
          isShow:false,
          url:''
        },
        prelang:"operation",
        options: {
          height:300,//默认高度-为了表头固定
          stripe: true, // 是否为斑马纹 table
          highlightCurrentRow: false, // 是否要高亮当前行
          border:true,//是否有纵向边框
          lazy:false,//是否需要懒加载
          fit:true,//列的宽度是否自撑开
          multiSelect:true,//
          seqNo:true,
          isRefresh:true,//是否显示刷新按钮
          isShowHide:true,//是否显示显影按钮
          isSearch:false,//高级查询按钮
          defaultOrderBy:{column:'id',direction:'desc'}
        },
        table: {
          total: 0,
          currentPage: 1,
          pageSize: 20,
          data:[],
          // 标题
          column: [
            //资源编号
            {minWidth:'140',prop:"resourceNo",label:"资源编号",sort: true,isTrue:true,formatter: (row, column, cellValue) => {return cellValue;},isSearch:true,searchInfoType:'text', render:{fun:this.addOrUpdateHandle}},
            //资源名称
            {minWidth:'120',prop: "resourceName",label:"资源名称",sort: true,isTrue:true,isSearch:true,searchInfoType:'text'},
           //备注
            {minWidth:'200',prop: "remark",label:"备注",sort: true,isTrue:true,isSearch:false,searchInfoType:'text'},
          ],
          toolbar: [
            {
              text: '新增',
              type: 'primary',
              fun: this.addOrUpdateHandle
            }
          ],
          operator:[
            {
              text: '删除',
              type: 'text',
              size: 'small',
              fun: this.deleteHandle
            }
          ],
          operatorConfig:{
            fixed:'right',
            label:'操作',
            width:100,
            minWidth:100
          }
        }
      }
    },
    computed: {
      ...mapGetters(['permissions'])
    },
    methods: {
      getData () {
        this.$refs.resourceTable.getDataList();
      },
      addOrUpdateHandle(row){
        this.visible=true
        this.$nextTick(() => {
          this.$refs.add.init(row==null?null:row.id)
        })
      },
      // 删除
      deleteHandle (row) {
        this.$confirm('是否确认删除资源名为:"'+row.resourceName+'"', '提示', {
          confirmButtonText: '确定',
          cancelButtonText: '取消',
          closeOnClickModal:false,
          type: 'warning'
        }).then(function () {
          return delObj(row.id)
        }).then(data => {
          this.$message.success('删除成功')
          this.getData()
        })
      },
      handleSelectionChange(val){
        this.multipleSelection = val
      }
    },
  }
</script>
